<?php
if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;

class NsFbPagePlugin extends Module implements WidgetInterface {

    public function __construct()
    {
        $this->name = 'nsfbpageplugin';
        $this->tab = 'front_office_features';
        $this->version = '1.0.0';
        $this->author = 'Natis.be';
        $this->author_url = 'http://www.myshoponweb.be';
        $this->need_instance = 0;
        $this->ps_versions_compliancy = [
            'min' => '1.7',
            'max' => _PS_VERSION_
        ];
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->trans('Facebook Page Plugin', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin');
        $this->description = $this->trans('Show Facebook page in box on your webshop', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin');

        $this->confirmUninstall = $this->trans('Warning: all the data saved in your database will be deleted. Are you sure you want uninstall this module?', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin');
    }

    public function isUsingNewTranslationSystem()
    {
        return true;
    }

    public function install()
    {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }

        if (!parent::install() ||
            !$this->registerHook('displayLeftColumn') ||
            !Configuration::updateValue('NSFBPAGEPLUGIN_SIZE', 'full')
        ) {
            return false;
        }

        return true;
    }

    public function uninstall()
    {
        if (!parent::uninstall() ||
            !Configuration::deleteByName('NSFBPAGEPLUGIN_SIZE')
        ) {
            return false;
        }

        return true;
    }

    public function getContent()
    {
        $output = null;

        if (Tools::isSubmit('btnSubmit')) {
            $size = strval(Tools::getValue('NSFBPAGEPLUGIN_SIZE'));

            if (
                !$size||
                empty($size)
            ) {
                $output .= $this->displayError($this->trans('Invalid Configuration value', [], 'Modules.Nsfbleftbanner.Nsfbleftbanner'));
            } else {
                Configuration::updateValue('NSFBPAGEPLUGIN_SIZE', $size);
                $output .= $this->displayConfirmation($this->trans('Settings updated', [], 'Modules.Nsfbleftbanner.Nsfbleftbanner'));
            }
        }

        return $output.$this->displayForm();
    }

    public function displayForm()
    {
        // Récupère la langue par défaut
        $defaultLang = (int)Configuration::get('PS_LANG_DEFAULT');

        // Initialise les champs du formulaire dans un tableau
        $form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->trans('Settings', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin'),
                ),
                'input' => array(
                    array(
                        'type' => 'select',
                        'label' => $this->trans('Type of box', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin'),
                        'name' => 'NSFBPAGEPLUGIN_SIZE',
                        'multiple' => false,
                        'options' => array(
                            'query' => array(
                                array('key' => 'full', 'name' => $this->trans('Full with articles', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin')),
                                array('key' => 'reduce', 'name' => $this->trans('Reduce without articles', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin')),
                            ),
                            'id' => 'key',
                            'name' => 'name'
                        )
                    )
                ),
                'submit' => array(
                    'title' => $this->trans('Save', [], 'Modules.Nsfbpageplugin.Nsfbpageplugin'),
                    'name'  => 'btnSubmit'
                )
            ),
        );

        $helper = new HelperForm();

        // Module, token et currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

        // Langue
        $helper->default_form_language = $defaultLang;

        // Charge la valeur de NS_MONMODULE_PAGENAME depuis la base
        $helper->fields_value['NSFBPAGEPLUGIN_SIZE'] = Configuration::get('NSFBPAGEPLUGIN_SIZE');

        return $helper->generateForm(array($form));
    }

    public function renderWidget($hookName = null, array $configuration = []){
        $this->context->smarty->assign($this->getWidgetVariables($hookName, $configuration));
        if ($hookName == "contactinfo") {
            return $this->display(__FILE__, 'contactinfo.tpl');
        } else {
            return $this->display(__FILE__, 'pluginpage.tpl');
        }

    }

    public function getWidgetVariables($hookName = null , array $configuration = [] )
    {
        return array (
                        "fburl" => Configuration::get("BLOCKSOCIAL_FACEBOOK"),
                        "boxsize" => Configuration::get("NSFBPAGEPLUGIN_SIZE")
        );
    }
}